@@ -63,7 +63,7 @@ class MessageBody:
             x = 0
             while x < len(payload):
                 uuid = self.getUuid(payload[x:x+16])
-                _LOGGER.debug("  uuid: {0} {1} {2}".format(type(uuid), len(uuid), uuid))
+                #_LOGGER.debug("  uuid: {0} {1} {2}".format(type(uuid), len(uuid), uuid))
 
                 e = payload[x+16:x+24]
                 #_LOGGER.debug("  e: {0} {1} {2}".format(type(e), len(e), e))
@@ -73,13 +73,13 @@ class MessageBody:
 
                 if uuid in config_data.fieldmap:
                     try:
-                        #_LOGGER.debug("UUID in fieldmap List {0}".format(uuid))
+                        _LOGGER.debug("UUID in fieldmap List {0}".format(uuid))
                         mapentry = config_data.fieldmap[uuid]
 
                         device = mapentry["device"]
                         stateName = mapentry["stateName"]
 
-                        #_LOGGER.debug("SettingValueState {0} {1} device_type: {2} state_name: {3}".format(device.id, device.name, device.device_type, mapentry["stateName"]))
+                        _LOGGER.debug("SettingValueState {0} {1} device_type: {2} state_name: {3}".format(device.id, device.name, device.device_type, mapentry["stateName"]))
 
                         device.set_value(stateName, dval)
 
@@ -207,7 +207,7 @@ class MessageBody:
 
 
                         else:
-                            #_LOGGER.debug("SettingTextState {0} {1} device_type: {2} state_name: {3}".format(device.id, device.name, device.device_type, mapentry["stateName"]))
+                            _LOGGER.debug("SettingTextState {0} {1} device_type: {2} state_name: {3}".format(device.id, device.name, device.device_type, mapentry["stateName"]))
 
                             device.set_value(stateName, text)
 
